#!/bin/bash

if [ ! "$BASH_VERSION" ] ; then
    bash $0 $1 $2 $3 $4 $5 $6 $7 $8 $9
    exit 1
fi

syntax-line-douple() {
echo -n "
==============================
"
}

syntax-line-single() {
echo -n "
------------------------------
"
}

start() {
    syntax-line-douple
    echo -n "Warén CLI "
    syntax-line-douple
}

login() {
    echo ">>> Login <<<"
    ORG=$2

    if [[ -z "$HOSTNAME" || ${#HOSTNAME} -lt 5 ]]; then
        stop
    fi

    if [[ $(hostname -d) == "devices.waren.io" ]]
    then
        ORG=warengroup
    elif [[ $(hostname -d) == "devices.cwinfo.net" ]]
    then
        ORG=cwinfo
    elif [[ $(hostname -d) == "devices.christerwaren.fi" ]]
    then
        ORG=cwchristerw
    elif [[ -z $ORG ]]
    then
        echo "Organization: Required"
        exit 1
    fi

    if [[ $ORG == "warengroup" ]]
    then
        DOMAIN=waren.io
    elif [[ $ORG == "cwinfo" ]]
    then
        DOMAIN=cwinfo.net
    elif [[ $ORG == "cwchristerw" ]]
    then
        DOMAIN=christerwaren.fi
    else
        echo "Organization: Unsupported"
        exit 1
    fi

    FOLDER=$ORG
    DEVICE_DOMAIN="devices.$DOMAIN"
    IDM_DOMAIN="idm.cwinfo.net"
    VAULT_DOMAIN="vault.cwinfo.net"
    GIT_DOMAIN="git.cwinfo.net"

    if [[ $(hostname -d) ]]
    then
        HOSTNAME=$(hostname --fqdn)
    elif [[ -z $(hostname -d) ]] && [[ ! -z $2 ]]
    then
        HOSTNAME="$2.$DEVICE_DOMAIN"
    else
        echo "Hostname: Required"
        exit 1
    fi

    if [[ -z $USER ]]
    then
        if [[ -z $SUDO_USER ]]
        then
            if [[ -z LOGNAME ]]
            then
                echo "Username: Required"
                exit 1
            else
                USER=$LOGNAME
            fi
        else
            USER=$SUDO_USER
        fi
    fi

    VAULT_STATUS=$(curl -s -o /dev/null -w "%{http_code}" https://$VAULT_DOMAIN/v1/sys/health)
    if [[ $VAULT_STATUS -eq 200 ]]
    then
        IDM_STATUS=$(curl -s -o /dev/null -w "%{http_code}" https://$IDM_DOMAIN)
        if [[ $IDM_STATUS -eq 301 ]]
        then
            echo "Organization: $ORG"
            if [[ -z $USER || $USER == "root" || $USER == "local" ]]
            then
                echo -n "Username: "
                read USERNAME
            else
                echo "Username: $USER"
                USERNAME=$USER
            fi

            echo -n "Password: "
            read -s PASSWORD
            echo -n "****************"
            VAULT_LOGIN=$(curl https://$VAULT_DOMAIN/v1/auth/ldap/login/$USERNAME -X POST -d '{ "password": "'$PASSWORD'" }' -s | jq -r '.auth.client_token')
            if [[ -z $VAULT_LOGIN || ${#VAULT_LOGIN} -lt 95 || ${#VAULT_LOGIN} -gt 95 ]]; then
                echo "Status: Login Failed"
                exit 1
            fi
        else
            echo "Organization: $ORG"
            echo "Status: IDM Offline"
            exit 1
        fi
    else
        echo "Organization: $ORG"
        echo "Status: Vault Offline"
        exit 1
    fi



    # VAULT_STATUS=$(curl -s -o /dev/null -w "%{http_code}" https://vault.$DOMAIN/v1/sys/health)
    # if [[ $VAULT_STATUS -eq 200 ]]; then
    #     export VAULT_ADDR="https://vault.$DOMAIN"
    #     VAULT_LOGIN=$(vault token lookup -address=https://vault.$DOMAIN 2> /dev/null)
    #     if [[ -z $VAULT_LOGIN ]]; then
    #         IDM_STATUS=$(curl -s -o /dev/null -w "%{http_code}" https://idm.$DOMAIN)
    #         if [[ $IDM_STATUS -eq 301 ]]; then
    #             echo "vault.$DOMAIN - Login"
    #             echo "Username: $USER"
    #             echo -n "Password: "
    #             export VAULT_ADDR="https://vault.$DOMAIN"
    #             VAULT_LOGIN=$(vault login -address=https://vault.$DOMAIN -method=ldap username=$USER 2> /dev/null)
    #             echo ""
    #             if [[ -z $VAULT_LOGIN ]]; then
    #                 exit 1
    #             fi
    #         else
    #             echo "vault.$DOMAIN - Login"
    #             echo -n "Token: "
    #             export VAULT_ADDR="https://vault.$DOMAIN"
    #             VAULT_LOGIN=$(vault login -address=https://vault.$DOMAIN -method=token 2> /dev/null)
    #             echo ""
    #             if [[ -z $VAULT_LOGIN || ${#VAULT_TOKEN} -lt 95 || ${#VAULT_TOKEN} -gt 95 ]]; then
    #                 exit 1
    #             fi
    #         fi
    #     fi
    # fi


    # if [[ $USER == "root" || $USER == "local" ]]
    # then
    #     echo "Status: Login Failed"
    # fi
    start
}

stop () {
    if [[ -d "./src" ]]
    then
        podman run -it --rm -v "$PWD":/usr/src/myapp -w /usr/src/myapp docker.io/library/php:8-cli php generator.php &> /dev/null
        mv wx.tmp wx &> /dev/null
        chmod +x wx &> /dev/null
    else
        sudo curl https://git.waren.io/warengroup/wx/raw/branch/master/wx -o /opt/wx &> /dev/null
        if [[ -d "/usr/bin" ]]
        then
            sudo ln -sf /opt/wx /usr/bin/wx &> /dev/null
        fi
        sudo chmod +x /usr/bin/wx &> /dev/null
    fi
    echo " "
    echo " "
    exit 1
}

{{ COMMANDS }}

start
if [[ ! -z $1 ]] && [[ $(type -t warencli-$1) == function ]]
then
    warencli-$1 $2 $3 $4 $5 $6 $7 $8 $9
fi
stop
